@@ -351,9 +351,7 @@ class AsyncKeys:
         if not untrusted_hmac:
             raise Issue.no_value_specified("untrusted_hmac")
         true_hmac = await cls.amake_hmac(data, key=key, hasher=hasher)
-        if await abytes_are_equal(untrusted_hmac, true_hmac):
-            return True
-        else:
+        if not await abytes_are_equal(untrusted_hmac, true_hmac):
             raise Issue.invalid_value("HMAC of data stream")
 
 
@@ -412,9 +410,7 @@ class Keys:
         if not untrusted_hmac:
             raise Issue.no_value_specified("untrusted_hmac")
         true_hmac = cls.make_hmac(data, key=key, hasher=hasher)
-        if bytes_are_equal(untrusted_hmac, true_hmac):
-            return True
-        else:
+        if not bytes_are_equal(untrusted_hmac, true_hmac):
             raise Issue.invalid_value("HMAC of data stream")
 
 
@@ -1315,7 +1311,7 @@ class PackageSigner:
     def _checksums(self):
         """
         Returns the instance's package filenames & their hexdigests in
-        a json ready dictionary.
+        a JSON ready dictionary.
         """
         return {
             filename: hasher.hexdigest()
@@ -1389,10 +1385,7 @@ class PackageSigner:
             salt=salt,
             **passcrypt_settings,
         )
-        self._db = Database.generate_profile(
-            tokens,
-            directory=directory if directory else Database.directory,
-        )
+        self._db = Database.generate_profile(tokens, directory=directory)
         try:
             self.db.query_tag(self._scope.package, cache=True)
         except LookupError:
